/**************************************************************************** 
*  Copyright 2009 C&H Technologies, Inc.  All Rights Reserved.					    * 
*****************************************************************************/
/****************************************************************************
*
*	m228_ansi.h
*
*	Header file for the M228 ANSI-C driver. 
*
*	C&H Part Number: 11030509
*
*****************************************************************************/
#ifndef	M228_HEADER
#define	M228_HEADER	


#ifndef	PLATFORM
#define PLATFORM chwin
#endif

#include	"apis.h"

/**************************************************************************** 
*  TypeDef's
*****************************************************************************/
typedef char Int8;
typedef unsigned char UInt8;
typedef unsigned short UInt16;
typedef int Int32;
typedef short Int16;
typedef unsigned int UInt32;
typedef unsigned short Bool;
typedef double Real64;

typedef struct
{	APIS_HANDLE apis_handle;
	UInt32			apis_error;
	Int32	input;
}M228_INSTR, *M228_HANDLE;


/*  Defines needed for the following typedefs  */
#define		M228_CAL_ENTRY_MAX_LABEL	11
#define		M228_CAL_ENTRY_MAX_DATE_SIZE	8
#define		M228_CAL_ENTRY_MAX_TIME_SIZE	6

typedef struct
{	UInt8 label[M228_CAL_ENTRY_MAX_LABEL+1];  //11 bytes plus a terminating 0
	Int8 date[M228_CAL_ENTRY_MAX_DATE_SIZE+1];
	Int8 time[M228_CAL_ENTRY_MAX_TIME_SIZE+1];
	UInt8 temperature;
	UInt8 cal_type;
	UInt8 front_end_config;
	UInt8 filter_config;
	UInt8 offset_cal_value;
	UInt8 full_scale_cal_value;
}M228_CALIBRATION_ENTRY;

typedef struct
{	Int32 cal_type; 					//0=unipolar positive, 1=bipolar, 2=unipolar negative
	Real64 offset_exp;
	Real64 offset_max;
	Real64 offset_min;
	Real64 fullscale_exp;
	Real64 fullscale_max;
	Real64 fullscale_min;
} M228_CALIBRATION_LIMITS;

/**************************************************************************** 
*  Error Codes
*****************************************************************************/
#define		M228_SUCCESS															0

#define		M228_SPECIFIC_ERROR_BASE									0xBFFC0900
#define		M228_ERROR_FIFO_EMPTY											(M228_SPECIFIC_ERROR_BASE + 0)
#define		M228_ERROR_PARAMETER1											(M228_SPECIFIC_ERROR_BASE + 1)
#define		M228_ERROR_PARAMETER2											(M228_SPECIFIC_ERROR_BASE + 2)
#define		M228_ERROR_PARAMETER3											(M228_SPECIFIC_ERROR_BASE + 3)
#define		M228_ERROR_PARAMETER4											(M228_SPECIFIC_ERROR_BASE + 4)
#define		M228_ERROR_PARAMETER5											(M228_SPECIFIC_ERROR_BASE + 5)
#define		M228_ERROR_PARAMETER6											(M228_SPECIFIC_ERROR_BASE + 6)
#define		M228_ERROR_PARAMETER7											(M228_SPECIFIC_ERROR_BASE + 7)
#define		M228_ERROR_PARAMETER8											(M228_SPECIFIC_ERROR_BASE + 8)
#define		M228_ERROR_PARAMETER9											(M228_SPECIFIC_ERROR_BASE + 9)
#define		M228_ERROR_PARAMETER10										(M228_SPECIFIC_ERROR_BASE + 10)
#define		M228_ERROR_FAIL_ID_QUERY									(M228_SPECIFIC_ERROR_BASE + 11)
#define		M228_ERROR_APIS														(M228_SPECIFIC_ERROR_BASE + 12)
#define		M228_ERROR_OUT_OF_MEMORY									(M228_SPECIFIC_ERROR_BASE + 13)	
#define		M228_ERROR_I2C_TIMEOUT										(M228_SPECIFIC_ERROR_BASE + 14)	
#define		M228_ERROR_CALIBRATION										(M228_SPECIFIC_ERROR_BASE + 15)	
#define		M228_ERROR_CALIBRATION_ABORTED						(M228_SPECIFIC_ERROR_BASE + 16)	
#define		M228_SPECIFIC_ERROR_END										(M228_SPECIFIC_ERROR_BASE + 17)
#define		M228_SPECIFIC_ERROR_ABSOLUTE_MAX					(M228_SPECIFIC_ERROR_BASE + 0x1FFF)


/**************************************************************************** 
*  Warning Codes
*****************************************************************************/
#define		M228_SPECIFIC_WARNING_BASE													0x3FFC0900
#define		M228_WARNING_NUM_SAMPLES_NOT_AVAILABLE							(M228_SPECIFIC_WARNING_BASE + 0)
#define		M228_WARNING_CALIBRATION_ENTRY_EMPTY								(M228_SPECIFIC_WARNING_BASE + 1)
#define		M228_WARNING_OVERVOLTAGE														(M228_SPECIFIC_WARNING_BASE + 2)
#define		M228_WARNING_UNDERVOLTAGE						 								(M228_SPECIFIC_WARNING_BASE + 3)
#define		M228_SPECIFIC_WARNING_END														(M228_SPECIFIC_WARNING_BASE + 4)
#define		M228_SPECIFIC_WARNING_ABSOLUTE_MAX									(M228_SPECIFIC_WARNING_BASE + 0x6FF)



/**************************************************************************** 
*	M228 Register Offsets & Bit Definitions
*****************************************************************************/
/*  ID Register  */
#define		M228_ID_REGISTER												0x00
#define		M228_CONFIG_BIT_MASK										0xFF00
#define		M228_CONFIG_BIT_NUM											8
#define		M228_MODEL_BIT_MASK											0x00FF
#define		M228_MODEL_BIT_NUM											0

/*  Revision Register  */
#define		M228_REVISION_REGISTER									0x02
#define		M228_LOGIC_MAJOR_REV_BIT_MASK						0x00F0
#define		M228_LOGIC_MAJOR_REV_BIT_NUM						4
#define		M228_LOGIC_MINOR_REV_BIT_MASK						0x000F
#define		M228_LOGIC_MINOR_REV_BIT_NUM						0

/*  Master Control Register  */
#define		M228_MASTER_CONTROL_REGISTER						0x04
#define		M228_STATUS_BIT_MASK										0xF800
#define		M228_FIFO_FULL_BIT_MASK									0x8000
#define		M228_FIFO_HALF_FULL_BIT_MASK						0x4000
#define		M228_FIFO_QTR_FULL_BIT_MASK							0x2000
#define		M228_FIFO_NOT_EMPTY_BIT_MASK						0x1000
#define		M228_TSR_BIT_MASK												0x0800
#define		M228_CCM_BIT_MASK												0x0400
#define		M228_RESET_FIFO_BIT_MASK								0x0200
#define		M228_RESET_TIME_STAMP_BIT_MASK					0x0100
#define		M228_STORAGE_MODE_BIT_MASK							0x00C0
#define		M228_STORAGE_MODE_BIT_NUM								6
#define		M228_FST_BIT_MASK												0x0008
#define		M228_ASEL_BIT_MASK											0x0004
#define		M228_ASEL_BIT_NUM												2
#define		M228_ACE_BIT_MASK												0x0002
#define		M228_TRUN_BIT_MASK											0x0001

/*  Interrupt Control Register  */
#define		M228_INTERRUPT_CONTROL_REGISTER									0x06
#define		M228_INTERRUPT_ENABLE_BIT_MASK									0x00F8
#define		M228_INTERRUPT_PENDING_BIT_MASK									0xF800
#define		M228_INTERRUPT_GLOBAL_ENABLE_BIT_MASK						0x0001
#define		M228_INTERRUPT_FIFO_FULL_ENABLE_MASK						0x0080
#define		M228_INTERRUPT_FIFO_HALF_FULL_ENABLE_MASK				0x0040
#define		M228_INTERRUPT_FIFO_QTR_FULL_ENABLE_MASK				0x0020
#define		M228_INTERRUPT_FIFO_NOT_EMPTY_ENABLE_MASK				0x0010
#define		M228_INTERRUPT_TIMESTAMP_ROLLOVER_ENABLE_MASK		0x0008
#define		M228_INTERRUPT_FIFO_FULL_BIT_NUM								7
#define		M228_INTERRUPT_FIFO_HALF_FULL_BIT_NUM						6
#define		M228_INTERRUPT_FIFO_QTR_FULL_BIT_NUM						5
#define		M228_INTERRUPT_FIFO_NOT_EMPTY_BIT_NUM						4
#define		M228_INTERRUPT_TIMESTAMP_ROLLOVER_BIT_NUM				3


/*  Function Source Control Register  */
#define		M228_FUNCTION_SOURCE_CONTROL_REGISTER		0x08
#define		M228_FST_SOURCE_INVERT_BIT_MASK					0x8000
#define		M228_FST_SOURCE_INVERT_BIT_NUM					15
#define		M228_FST_SOURCE_BIT_MASK								0x7000
#define		M228_FST_SOURCE_BIT_NUM									12
#define		M228_ASEL_SOURCE_INVERT_BIT_MASK				0x0800
#define		M228_ASEL_SOURCE_INVERT_BIT_NUM					11
#define		M228_ASEL_SOURCE_BIT_MASK								0x0700
#define		M228_ASEL_SOURCE_BIT_NUM								8
#define		M228_ACE_SOURCE_INVERT_BIT_MASK					0x0080
#define		M228_ACE_SOURCE_INVERT_BIT_NUM					7
#define		M228_ACE_SOURCE_BIT_MASK								0x0070
#define		M228_ACE_SOURCE_BIT_NUM									4
#define		M228_TRUN_SOURCE_INVERT_BIT_MASK				0x0008
#define		M228_TRUN_SOURCE_INVERT_BIT_NUM					3
#define		M228_TRUN_SOURCE_BIT_MASK								0x0007
#define		M228_TRUN_SOURCE_BIT_NUM								0
#define		M228_FORCE_STORE_ALL_FUNCTION						0
#define		M228_APERTURE_SELECT_FUNCTION						1
#define		M228_A2D_CONV_ENABLE_FUNCTION						2
#define		M228_TIMESTAMP_RUN_ENABLE_FUNCTION			3
#define		M228_SOFTWARE_REGISTER									0	// do not use for SCLK
#define		M228_FPINA_SIGNAL												2
#define		M228_FPINB_SIGNAL												3
#define		M228_MTRIGINA_SIGNAL										4
#define		M228_MTRIGINB_SIGNAL										5
														 
/*  Clock/Aperture Control Register  */
#define		M228_CLOCK_APERTURE_CONTROL_REGISTER		0x0A
#define		M228_SOFTWARE_CLK_BIT_MASK							0x8000
#define		M228_SOFTWARE_CLK_BIT_NUM								15
#define		M228_CLKSRC_BIT_MASK										0x0007
#define		M228_CLKSRC_BIT_NUM											0
#define		M228_PSC_BIT_MASK												0x00F0
#define		M228_PSC_BIT_NUM												4
#define		M228_APMODE_BIT_MASK										0x0700
#define		M228_APMODE_BIT_NUM											8
#define		M228_INTERNAL_OSCILLATOR								0
#define		M228_SOFTWARE_REGISTER_SCLK							1
// use FPINx/MTRIGINx_SIGNAL defines in Function Source Control Reg for those signals

/*  Output Source Control Register  */
#define		M228_OUTPUT_SOURCE_CONTROL_REGISTER			0x0C
#define		M228_OUTPUT_A														0
#define		M228_OUTPUT_B														1
#define		M228_TRIG_OUTB_INVERT_BIT_MASK					0x8000
#define		M228_TRIG_OUTB_INVERT_BIT_NUM						15
#define		M228_TRIG_OUTB_SOURCE_BIT_MASK					0x7000
#define		M228_TRIG_OUTB_SOURCE_BIT_NUM						12
#define		M228_TRIG_OUTA_INVERT_BIT_MASK					0x0800
#define		M228_TRIG_OUTA_INVERT_BIT_NUM						11
#define		M228_TRIG_OUTA_SOURCE_BIT_MASK					0x0700
#define		M228_TRIG_OUTA_SOURCE_BIT_NUM						8
#define		M228_FPOUTB_INVERT_BIT_MASK							0x0080
#define		M228_FPOUTB_INVERT_BIT_NUM							7
#define		M228_FPOUTB_SOURCE_BIT_MASK							0x0070
#define		M228_FPOUTB_SOURCE_BIT_NUM							4
#define		M228_FPOUTA_INVERT_BIT_MASK							0x0008
#define		M228_FPOUTA_INVERT_BIT_NUM							3
#define		M228_FPOUTA_SOURCE_BIT_MASK							0x0007
#define		M228_FPOUTA_SOURCE_BIT_NUM							0

#define		M228_DISABLED_INPUT											0
#define		M228_SAMPLE_CLOCK_AFTER_PRESCLALER			1
#define		M228_CLOCK_BEFORE_PRESCALER							2
#define		M228_FORCE_STORE												3
#define		M228_APERTURE_SELECT										4
#define		M228_A2D_CONVSERSION_ENABLE							5
#define		M228_TIMESTAMP_RUN_ENABLE								6
#define		M228_VALUE_STORED_STROBE								7

/*  Input Control Registers  */
#define		M228_INPUT_A_CONTROL_REGISTER						0x10					
#define		M228_INPUT_B_CONTROL_REGISTER						0x12
#define		M228_INPUT_A														0
#define		M228_INPUT_B														1
#define		M228_CLEAR_LATCHED_BIT_MASK							0xC000
#define		M228_CLEAR_LATCHED_TRIG_BIT_MASK				0x8000
#define		M228_CLEAR_LATCHED_TRIG_BIT_NUM					15
#define		M228_CLEAR_LATCHED_FPIN_BIT_MASK				0x4000
#define		M228_CLEAR_LATCHED_FPIN_BIT_NUM					14
#define		M228_TRIG_STATUS_BIT_MASK								0x8000
#define		M228_TRIG_STATUS_BIT_NUM								15
#define		M228_FPIN_STATUS_BIT_MASK								0x4000
#define		M228_FPIN_STATUS_BIT_NUM								14
#define		M228_FPIN_IMPEDANCE_BIT_MASK						0x1000
#define		M228_FPIN_IMPEDANCE_BIT_NUM							12
#define		M228_TRIG_INVERT_BIT_MASK								0x0800
#define		M228_TRIG_INVERT_BIT_NUM								11
#define		M228_FPIN_INVERT_BIT_MASK								0x0400
#define		M228_FPIN_INVERT_BIT_NUM								10
#define		M228_TRIG_LATCH_BIT_MASK								0x0200
#define		M228_TRIG_LATCH_BIT_NUM									9
#define		M228_FPIN_LATCH_BIT_MASK								0x0100
#define		M228_FPIN_LATCH_BIT_NUM									8
#define		M228_FPIN_THRESHOLD_BIT_MASK						0x00FF
#define		M228_FPIN_THRESHOLD_BIT_NUM							0
#define		M228_FPIN_THRESHOLD_OFFSET							0.0
#define		M228_FPIN_THRESHOLD_RESOLUTION					(5.0/(Real64)(0xFF))

/*  Aperture High/Low Registers  */
#define		M228_APERTURE_HIGH_A_REGISTER						0x14
#define		M228_APERTURE_LOW_A_REGISTER						0x16
#define		M228_APERTURE_HIGH_B_REGISTER						0x18
#define		M228_APERTURE_LOW_B_REGISTER						0x1A
#define		M228_APERTURE_SELECT_A									0
#define		M228_APERTURE_SELECT_B									1

/*  Fifo Data Port Register  */
#define		M228_FIFO_DATA_REGISTER									0x20
#define		M228_DATA_VALID_BIT_MASK								0x8000
#define		M228_DATA_14_BIT_MASK										0x3FFF

/*  Fifo Unread Count Registers  */
#define		M228_FIFO_UNREAD_COUNT_REGISTER_HIGH		0x24
#define		M228_FIFO_UNREAD_COUNT_REGISTER_LOW			0x26


/*  Last Value Stored Register  */
#define		M228_LAST_VALUE_STORED_REGISTER					0x28

/*  Current Value Register  */
#define		M228_CURRENT_VALUE_REGISTER							0x2A

/*  Timestamp Registers  */
#define		M228_TIMESTAMP_REGISTER_HIGH						0x2C
#define		M228_TIMESTAMP_REGISTER_LOW							0x2E

/*  Peripheral Variable Voltage Register  */
#define		M228_PERIPHERAL_VAR_VOLTAGE_REGISTER		0x30
#define		M228_PVARV_OFFSET												10.0									// the Analog Daughter has a Gain = 2
#define		M228_PVARV_RESOLUTION										(20.0/(Real64)(0xFFF))	// "


/*  Random Data Port Register  */
#define		M228_RANDOM_DATA_PORT_REGISTER					0x34

/*  Random Data Address Register  */
#define		M228_RANDOM_DATA_ADDRESS_REGISTER				0x38
#define		M228_RANDOM_DATA_ADDRESS_REGISTER_HIGH	M228_RANDOM_DATA_ADDRESS_REGISTER
#define		M228_RANDOM_DATA_ADDRESS_REGISTER_LOW		M228_RANDOM_DATA_ADDRESS_REGISTER + 2

/*  Analog Input Control Register  */
#define		M228_ANALOG_INPUT_CONTROL_REGISTER			0x40
#define		M228_REFE_BIT_MASK											0x8000
#define		M228_REFE_BIT_NUM												15
#define		M228_REFSEL_BIT_MASK										0x7000
#define		M228_REFSEL_BIT_NUM											12
#define		M228_SIM_BIT_MASK												0x0C00
#define		M228_SIM_BIT_NUM												10
#define		M228_FT_BIT_MASK												0x0200
#define		M228_FT_BIT_NUM													9
#define		M228_WARP_BIT_MASK											0x0100
#define		M228_WARP_BIT_NUM												8
#define		M228_IVDD_BIT_MASK											0x0080
#define		M228_IVDD_BIT_NUM												7
#define		M228_FGAIN_BIT_MASK											0x0030
#define		M228_FGAIN_BIT_NUM											4
#define		M228_BGAIN_BIT_MASK											0x0007
#define		M228_BGAIN_BIT_NUM											0

/*  Anti-Aliasing Filter Control Register  */
#define		M228_FILTER_CONTROL_REGISTER						0x42
#define		M228_FCUTOFF_BIT_MASK										0x0F00
#define		M228_FCUTOFF_BIT_NUM										8
#define		M228_FSEL_BIT_MASK											0x0003
#define		M228_FSEL_BIT_NUM												0
#define		M228_FILTER_BYPASS											0
#define		M228_FILTER_ELLIPTIC										1
#define		M228_FILTER_BESSEL											2
#define		M228_FILTER_ELLIPTIC_1600HZ							0
#define		M228_FILTER_ELLIPTIC_3200HZ							1
#define		M228_FILTER_ELLIPTIC_6500HZ							2
#define		M228_FILTER_ELLIPTIC_13KHZ							3
#define		M228_FILTER_ELLIPTIC_26KHZ							4
#define		M228_FILTER_ELLIPTIC_52KHZ							5
#define		M228_FILTER_ELLIPTIC_104KHZ							6
#define		M228_FILTER_BESSEL_300HZ								0
#define		M228_FILTER_BESSEL_600HZ								1
#define		M228_FILTER_BESSEL_1400HZ								2
#define		M228_FILTER_BESSEL_2800HZ								3
#define		M228_FILTER_BESSEL_5500HZ								4
#define		M228_FILTER_BESSEL_11KHZ								5
#define		M228_FILTER_BESSEL_22KHZ								6
#define		M228_FILTER_BESSEL_44KHZ								7
#define		M228_FILTER_BESSEL_88KHZ								8

/* A/D Temperature Register */
#define		M228_A2D_TEMPERATURE_REGISTER						0x44
#define		M228_DISABLE_TEMP_READ_BIT_MASK					0x8000
#define		M228_DISABLE_TEMP_READ_BIT_NUM					15

/*  Cal Fullscale/Offset Register  */
#define		M228_CAL_FULLSCALE_OFFSET_REGISTER			0x46
#define		M228_FSVAL_BIT_MASK											0xFF00
#define		M228_FSVAL_BIT_NUM											8
#define		M228_OSVAL_BIT_MASK											0x00FF
#define		M228_OSVAL_BIT_NUM											0

/*  Cal EEPROM Control Register  */
#define		M228_CAL_EEPROM_CONTROL_REGISTER				0x48
#define		M228_I2C_OPC_BIT_MASK										0x8000
#define		M228_I2C_OPC_BIT_NUM										15
#define		M228_I2C_ERROR_BIT_MASK									0x4000
#define		M228_I2C_ERROR_BIT_NUM									14
#define		M228_WRITE_EEPROM_BIT_MASK							0x2000
#define		M228_WRITE_EEPROM_BIT_NUM								13
#define		M228_READ_EEPROM_BIT_MASK								0x1000
#define		M228_READ_EEPROM_BIT_NUM								12
#define		M228_EEPROM_ADDR_BIT_MASK								0x01FF
#define		M228_EEPROM_ADDR_BIT_NUM								0

/*  Cal EEPROM Data Register  */
#define		M228_CAL_EEPROM_DATA_REGISTER						0x4A

/*  IDPROM Register */
#define		M228_ID_ACCESS_REGISTER									0xFE
#define		M228_IDENT_WORD_SYNC_CODE								0
#define		M228_IDENT_WORD_MODULE_NUM							1
#define		M228_IDENT_WORD_REVISION_NUM 						2
#define		M228_IDENT_WORD_MODULE_CHAR 						3
#define		M228_IDENT_WORD_VXI_SYNC_CODE 					16
#define		M228_IDENT_WORD_VXI_ID 									17
#define		M228_IDENT_WORD_VXI_DEVICE_TYPE  				18
#define		M228_VXI_MANF_ID												0xFC1
#define		M228_VXI_MODEL_CODE											0xFD4


/**************************************************************************** 
*	Misc.
*****************************************************************************/
#define		M228_TRUE																1
#define		M228_FALSE															0

#define		M228_FIFO_SIZE													33554432
#define		M228_A2D_RESOLUTION											(19.998779/(Real64)0x3FFF)

#define		M228_MAX_CAL_MESSAGE_LENGTH							1024

/**************************************************************************** 
*	Exported Function Prototypes
*****************************************************************************/

Int32 m228_Init (Int32 instr, Bool IDQuery, Bool reset, M228_HANDLE *handle);
Int32 m228_QueryModuleIdentification (M228_HANDLE handle, UInt8 *model, UInt8 *config, UInt8 *log_major_rev, UInt8 *log_minor_rev);
Int32 m228_FifoUnreadCount (M228_HANDLE handle, UInt32 *unreadCount);
Int32 m228_QueryFifoStatus (M228_HANDLE handle, Bool *fifoFull, Bool *fifoHalfFull, Bool *fifoQtrFull, Bool *fifoNotEmpty);
Int32 m228_ResetFifo (M228_HANDLE handle);
Int32 m228_ResetTimeStamp (M228_HANDLE handle);
Int32 m228_QueryTimestamp (M228_HANDLE handle, UInt32 *timestamp);
Int32 m228_QueryTimestampRollover (M228_HANDLE handle, Bool *ts_rollover);

Int32 m228_ConfigureAnalogFrontEnd (M228_HANDLE handle, Bool divider, UInt8 front_end_gain, UInt8 back_end_gain);
Int32 m228_QueryAnalogFrontEndConfiguration (M228_HANDLE handle, Bool *divider, UInt8 *front_end_gain, UInt8 *back_end_gain);
Int32 m228_SimulationMode (M228_HANDLE handle, UInt8 mode, Bool factory_test);
Int32 m228_QuerySimulationMode (M228_HANDLE handle, UInt8 *mode, Bool *factory_test);
Int32 m228_ConfigureReferenceInjection (M228_HANDLE handle, Bool ref_enable, UInt8 ref_select);
Int32 m228_QueryReferenceInjection (M228_HANDLE handle, Bool *ref_enable, UInt8 *ref_select);
Int32 m228_CurrentValue (M228_HANDLE handle, Real64 *real_value, UInt16 *raw_value);
Int32 m228_SetPeripheralVoltage (M228_HANDLE handle, Real64 voltage);
Int32 m228_QueryPeripheralVoltage (M228_HANDLE handle, Real64 *voltage);
Int32 m228_LastStoredValue (M228_HANDLE handle, Real64 *last_stored, UInt16 *last_stored_raw);

Int32 m228_ResetTimestampRollover (M228_HANDLE handle);
Int32 m228_SoftwareClock (M228_HANDLE handle);
Int32 m228_Run (M228_HANDLE handle, Bool ts_run, Bool conv_enable);
Int32 m228_QueryRun (M228_HANDLE handle, Bool *ts_run, Bool *conv_enable);

Int32 m228_ConfigureSampleClock (M228_HANDLE handle, UInt8 source, UInt8 prescaler);
Int32 m228_QuerySampleClockConfiguration (M228_HANDLE handle, UInt8 *source, UInt8 *prescaler);
Int32 m228_ConfigureWarpMode (M228_HANDLE handle, Bool warp_mode);
Int32 m228_QueryWarpMode (M228_HANDLE handle, Bool *warp_mode);

Int32 m228_QueryFilterConfiguration (M228_HANDLE handle, UInt8 *cutoff, UInt8 *select);
Int32 m228_ConfigureFilter (M228_HANDLE handle, UInt8 cutoff, UInt8 select);

Int32 m228_ReadFifo (M228_HANDLE handle, Bool width, UInt32 *timestamp, Real64 *value, UInt16 *raw_data);
Int32 m228_ReadFifoBuffer (M228_HANDLE handle, Bool width32bit, UInt32 count, UInt32 *timestamp, Real64 *value, UInt16 *rawData, UInt32 *num_read);

Int32 m228_ConfigureApertureMode (M228_HANDLE handle, UInt8 aperture_mode);
Int32 m228_QueryApertureMode (M228_HANDLE handle, UInt8 *aperture_mode);
Int32 m228_ApertureSelect (M228_HANDLE handle, Bool aperture_select);
Int32 m228_QueryApertureSelect (M228_HANDLE handle, Bool *aperture_select);

Int32 m228_SetRawAperture (M228_HANDLE handle, Bool aperture_select, UInt16 aperture_high, UInt16 aperture_low);
Int32 m228_QueryAperture (M228_HANDLE handle, Bool aperture_select, UInt16 *aperture_high_raw, UInt16 *aperture_low_raw, Real64 *aperture_high, Real64 *aperture_low);

Int32 m228_ForceStore (M228_HANDLE handle, Bool force_store);
Int32 m228_QueryForceStore (M228_HANDLE handle, Bool *force_store);
Int32 m228_DataStorageMode (M228_HANDLE handle, UInt8 storage_mode);
Int32 m228_QueryDataStorageMode (M228_HANDLE handle, UInt8 *storage_mode);
Int32 m228_DataCaptureMode (M228_HANDLE handle, Bool continuous_capture);
Int32 m228_QueryDataCaptureMode (M228_HANDLE handle, Bool *continuous_capture);

Int32 m228_CalibrationOffsetAdjust (M228_HANDLE handle, UInt8 offsetAdjustment);
Int32 m228_QueryCalibrationOffsetAdjust (M228_HANDLE handle, UInt8 *offsetAdjustment);
Int32 m228_CalibrationFullScaleAdjust (M228_HANDLE handle, UInt8 fullScaleAdjustment);
Int32 m228_QueryCalibrationFullScaleAdjust (M228_HANDLE handle, UInt8 *fullScaleAdjustment);
																																																																																
Int32 m228_ConvertToVoltage(M228_HANDLE handle, UInt16 *raw_data, Real64 *voltage, UInt32 num_pooints, Bool read_module, Bool divider, UInt8 fgain, UInt8 bgain);
Int32 m228_ConvertToRaw(M228_HANDLE handle, Real64 *real_value , UInt16 *raw_data, UInt32 num_points, Bool read_module, Bool divider, UInt8 fgain, UInt8 bgain);

Int32 m228_ConfigureFunctionSource (M228_HANDLE handle, UInt8 function, UInt8 source, Bool invert);
Int32 m228_QueryFunctionSource (M228_HANDLE handle, UInt8 function, UInt8 *source, Bool *invert);

Int32 m228_ConfigureFrontPanelOutput (M228_HANDLE handle, Bool channel, UInt8 source, Bool invert);
Int32 m228_QueryFrontPanelOutput (M228_HANDLE handle, Bool channel, UInt8 *source, Bool *invert);
Int32 m228_ConfigureBackplaneTriggerOutput (M228_HANDLE handle, Bool channel, UInt8 source, Bool invert);
Int32 m228_QueryBackplaneTriggerOutput (M228_HANDLE handle, Bool channel, UInt8 *source, Bool *invert);

Int32 m228_ConfigureFrontPanelInput (M228_HANDLE handle, Bool channel, Bool impedance, Real64 threshold, Bool invert, Bool latch);
Int32 m228_QueryFrontPanelInput (M228_HANDLE handle, Bool channel, Bool *impedance, Real64 *threshold, Bool *invert, Bool *latch);
Int32 m228_ConfigureBackplaneTriggerInput (M228_HANDLE handle, Bool channel, Bool invert, Bool latch);
Int32 m228_QueryBackplaneTriggerInput (M228_HANDLE handle, Bool channel, Bool *invert, Bool *latch);
Int32 m228_QueryInputState (M228_HANDLE handle, Bool *fpina, Bool *fpinb, Bool *triga, Bool *trigb);
Int32 m228_ClearLatchedInput (M228_HANDLE handle, UInt8 input);

Int32 m228_ConfigureA2DTemperature (M228_HANDLE handle, Bool enable);
Int32 m228_QueryA2DTemperature (M228_HANDLE handle, Real64 *temperature, Bool *enabled);
Int32 m228_WriteEEPROMValue (M228_HANDLE handle, UInt16 address, UInt16 data);
Int32 m228_ReadEEPROMValue (M228_HANDLE handle, UInt16 address, UInt16 *data);
Int32 m228_FormatEEPROM (M228_HANDLE handle);
Int32 m228_QueryEEPROMFormatted (M228_HANDLE handle, Bool *formatted);
Int32 m228_GetCalibrationEntry (M228_HANDLE handle, UInt8 entry_num, M228_CALIBRATION_ENTRY *entry);
Int32 m228_StoreCalibrationEntry (M228_HANDLE handle, UInt8 entry_num, M228_CALIBRATION_ENTRY *entry);

Int32 m228_EnableInterrupts (M228_HANDLE handle,  Bool fifoFull,  Bool fifoHalfFull, Bool fifoQtrFull, Bool fifoNotEmpty, Bool timestampRollover);
Int32 m228_QueryInterruptsEnable (M228_HANDLE handle,  Bool *fifoFull,  Bool *fifoHalfFull, Bool *fifoQtrFull, Bool *fifoNotEmpty, Bool *timestampRollover);
Int32 m228_ClearInterrupts (M228_HANDLE handle,  Bool fifoFull,  Bool fifoHalfFull, Bool fifoQtrFull, Bool fifoNotEmpty, Bool timestampRollover);
Int32 m228_GetInterruptPending (M228_HANDLE handle,  Bool *fifoFull,  Bool *fifoHalfFull, Bool *fifoQtrFull, Bool *fifoNotEmpty, Bool *timestampRollover);

Int32 m228_ReadRandomDataPort (M228_HANDLE handle, Bool width32bit, UInt32 *timeStamp, Real64 *value, UInt16 *rawData);
Int32 m228_SetRandomDataAddressPointer (M228_HANDLE handle, UInt32 address);
Int32 m228_GetRandomDataAddressPointer (M228_HANDLE handle, UInt32 *address);

Int32 m228_CalibrateToInternalReference(M228_HANDLE handle, Bool offset_only, Bool divider, UInt8 fgain, UInt8 bgain, UInt8 filter_type, UInt8 filter_cutoff, M228_CALIBRATION_LIMITS *limits, Bool *abort, void (*user_CalMessage)(Int8 *));

Int32 m228_UninstallIrq (M228_HANDLE handle);
Int32 m228_InstallIrq (M228_HANDLE handle, void *interruptHandler, Int32 vector, Int32 level, Int32 mode, void *var_ptr);
Int32 m228_Reset (M228_HANDLE handle);
Int32 m228_RevisionQuery (Int8 driverRev[]);
Int32 m228_ErrorMessage (Int32 statusCode, Int8 errorMessage[]);
Int32 m228_ReadRegister16 (M228_HANDLE handle, UInt16 offset, UInt16 *value);
Int32 m228_ReadRegister32 (M228_HANDLE handle, UInt16 offset, UInt32 *value);
Int32 m228_WriteRegister16 (M228_HANDLE handle, UInt16 offset, UInt16 value);
Int32 m228_WriteRegister32 (M228_HANDLE handle, UInt16 offset, UInt32 value);
Int32 m228_GetIdentWord (M228_HANDLE handle, UInt16 offset, UInt16 *value);
Int32 m228_Close (M228_HANDLE handle);
Int32 m228_GetApisError (M228_HANDLE handle, UInt32 *apis_error);

#endif






